@@ -24,25 +24,27 @@ class ImageGenerator(
         Initializes CLIP, augmentations and set a device.
         """
         super(ImageGenerator, self).__init__()
-            
+
         self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
         print(f"USING {self.device}")
 
-        self.clip_input_img_size = 224
-
+        jit = True if float(torch.__version__[:3]) < 1.8 else False
         self.clip_model, _clip_preprocess = clip.load(
             "ViT-B/32",
+            jit=jit,
             device=self.device,
         )
         self.clip_model = self.clip_model.eval()
 
+        self.clip_input_img_size = self.clip_model.visual.input_resolution
+
         self.clip_norm_trans = torchvision.transforms.Normalize(
             (0.48145466, 0.4578275, 0.40821073),
             (0.26862954, 0.26130258, 0.27577711),
         )
 
         self.aug_transform = torch.nn.Sequential(
-            torchvision.transforms.RandomHorizontalFlip(),
+            torchvision.transforms.RandomHorizontalFlip(p=0.7, ),
             torchvision.transforms.RandomApply(
                 torch.nn.ModuleList([
                     torchvision.transforms.RandomAffine(
@@ -98,8 +100,8 @@ class ImageGenerator(
     def augment(
         self,
         img_batch,
-        target_img_width: int,
-        target_img_height: int,
+        target_img_width: int = None,
+        target_img_height: int = None,
         crop_scaler: int = 1,
         num_crops=64,
     ):
@@ -108,18 +110,20 @@ class ImageGenerator(
         transformations and additive noise
 
         Args:
-            img_batch (torch.Tensor): batch of images to augment
-                with shape BxHxWx3.
-            target_img_width (int): width of the augmented images.
-            target_img_height (int): height of the augmented images.
-            num_crops (int, optional): Number of augmentations to
-                generate. Defaults to 32.
-            crop_scaler (int, optional): Scale range used when
-                cropping. Defaults to 1.
+            img_batch (torch.Tensor): batch of images to augment with shape BxHxWx3.
+            target_img_width (int, optional): width of the augmented images. Defaults to img size.
+            target_img_height (int, optional): height of the augmented images. Defaults to img size
+            num_crops (int, optional): Number of augmentations to generate. Defaults to 32.
+            crop_scaler (int, optional): Scale range used when cropping. Defaults to 1.
 
         Returns:
             torch.Tensor: augmented batch of images.
         """
+        if target_img_height is None:
+            target_img_height = img_batch.shape[1]
+        if target_img_width is None:
+            target_img_width = img_batch.shape[2]
+
         pad_scale = 3
         x_pad_size = target_img_width // pad_scale
         y_pad_size = target_img_height // pad_scale
@@ -205,6 +209,7 @@ class ImageGenerator(
     def get_clip_img_encodings(
         self,
         img_batch: torch.Tensor,
+        do_normalize: bool = True,
         do_preprocess: bool = True,
     ) -> torch.Tensor:
         """
@@ -212,8 +217,8 @@ class ImageGenerator(
 
         Args:
             img_batch (torch.Tensor): input batch of images.
-            do_preprocess (bool, optional): if `True` the input 
-                images are normalized and resized. Defaults to True.
+            do_normalize (bool, optional): if `True` the embeddings are normalized. Defaults to True
+            do_preprocess (bool, optional): if `True` the input images are normalized and resized. Defaults to True.
 
         Returns:
             torch.Tensor: batched encodings of the input images.
@@ -226,19 +231,23 @@ class ImageGenerator(
             )
 
         img_logits = self.clip_model.encode_image(img_batch)
-        img_logits = img_logits / img_logits.norm(dim=-1, keepdim=True)
+
+        if do_normalize:
+            img_logits = img_logits / img_logits.norm(dim=-1, keepdim=True)
 
         return img_logits
 
     def get_clip_text_encodings(
         self,
         text: str,
+        do_normalize: bool = True,
     ):
         """
         Returns the CLIP encoding of an input text.
 
         Args:
             text (str): input text.
+            do_normalize (bool, optional): if `True` the embeddings are normalized. Defaults to True
 
         Returns:
             torch.Tensor: encoding of the input text.
@@ -247,7 +256,9 @@ class ImageGenerator(
         tokenized_text = tokenized_text.to(self.device).detach().clone()
 
         text_logits = self.clip_model.encode_text(tokenized_text)
-        text_logits = text_logits / text_logits.norm(dim=-1, keepdim=True)
+
+        if do_normalize:
+            text_logits = text_logits / text_logits.norm(dim=-1, keepdim=True)
 
         return text_logits
 
