@@ -232,6 +232,7 @@ class Aphantasia(ImageGenerator):
         height: int = 256,
         width: int = 256,
         generation_cb=None,
+        init_embed: torch.Tensor = None,
     ) -> Tuple[List[PIL.Image.Image], List[torch.Tensor]]:
         """
         Returns a list of images generated while optimizing
@@ -253,21 +254,29 @@ class Aphantasia(ImageGenerator):
                 inputs of this function will be the generated image
                 from the VQGAN (Nx3xHxW) and the logits used to 
                 generate it (Nx256xDxD) and the optimization step.
+            init_embed (torh.Tensor, optional): initial embedding 
+                From where to start the generation. Defaults to None.
 
         Returns:
             Tuple[List[PIL.Image.Image], List[torch.Tensor]]: list 
                 of optimized images and their respective fft
                 encodings.
         """
-        fft_img, img_freqs = self.get_fft_img(
-            height,
-            width,
-            batch_size=1,
-            std=0.01,
-            return_img_freqs=True,
-        )
 
-        fft_img = fft_img.to(self.device)
+        if init_embed is not None:
+            fft_img = torch.nn.Parameter(init_embed.to(self.device))
+
+        else:
+            fft_img, img_freqs = self.get_fft_img(
+                height,
+                width,
+                batch_size=1,
+                std=0.01,
+                return_img_freqs=True,
+            )
+
+            fft_img = fft_img.to(self.device)
+
         fft_img.requires_grad = True
 
         scale = self.get_scale_from_img_freqs(
